package model

import (
	"context"
	"fmt"
	"github.com/zeromicro/go-zero/core/stores/sqlc"
	"github.com/zeromicro/go-zero/core/stores/sqlx"
	"strings"
)

var _ DcWorkingPumpModel = (*customDcWorkingPumpModel)(nil)

type (
	// DcWorkingPumpModel is an interface to be customized, add more methods here,
	// and implement the added methods in customDcWorkingPumpModel.
	DcWorkingPumpModel interface {
		dcWorkingPumpModel
		FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingPump, error)
		Search(ctx context.Context, projectId int64, deviceCode, st, et string, offset, limit int64, orderBy string) ([]DcWorkingPump, error)
	}

	customDcWorkingPumpModel struct {
		*defaultDcWorkingPumpModel
	}
)

// NewDcWorkingPumpModel returns a model for the database table.
func NewDcWorkingPumpModel(conn sqlx.SqlConn) DcWorkingPumpModel {
	return &customDcWorkingPumpModel{
		defaultDcWorkingPumpModel: newDcWorkingPumpModel(conn),
	}
}

func (m *defaultDcWorkingPumpModel) Search(ctx context.Context, projectId int64, deviceCode, st, et string, offset, limit int64, orderBy string) ([]DcWorkingPump, error) {
	var resp []DcWorkingPump

	condition := []string{"`project_id`=?", "`device_code`=?"}
	vars := []interface{}{projectId, deviceCode}

	if st != "" {
		condition = append(condition, "`c_time`>=?")
		vars = append(vars, st)
	}

	if et != "" {
		condition = append(condition, "`c_time`<?")
		vars = append(vars, et)
	}

	if orderBy == "" {
		orderBy = "id desc"
	}

	query := fmt.Sprintf("select %s from %s where %s order by %s limit %d, %d", dcWorkingPumpRows, m.table, strings.Join(condition, " and "), orderBy, offset, limit)
	err := m.conn.QueryRowsCtx(ctx, &resp, query, vars...)
	switch err {
	case nil:
		return resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}

func (m *defaultDcWorkingPumpModel) FindOneByCode(ctx context.Context, projectId int64, deviceCode string) (*DcWorkingPump, error) {
	var resp DcWorkingPump
	query := fmt.Sprintf("select %s from %s where `project_id` = ? and `device_code` = ? order by c_time desc limit 1", dcWorkingPumpRows, m.table)
	err := m.conn.QueryRowCtx(ctx, &resp, query, projectId, deviceCode)
	switch err {
	case nil:
		return &resp, nil
	case sqlc.ErrNotFound:
		return nil, ErrNotFound
	default:
		return nil, err
	}
}
